@@ -147,9 +147,9 @@ class Accountant:
         return operation
 
     @staticmethod
-    def create_book(account_id: str):
+    def create_book(account_id: str, ledger_host):
         log.info("---------New_ledger-------------")
-        ledger = LedgerClient(ledger_host="http://ledger-service-dev-1.local-dev:3000/")
+        ledger = LedgerClient(ledger_host=ledger_host)
         block_book_id = ledger.create_book(name=f"{account_id}_block_book", min_balance=0)
         main_book_id = ledger.create_book(name=f"{account_id}_main_book", min_balance=0)
         new_books = {
@@ -160,4 +160,3 @@ class Accountant:
         }
         log.info(new_books)
         return new_books
-
